==> impact-0.0.4.tar.gz: lib/11_Images/1_Single_Image.dart <==
import 'dart:convert';
import 'package:file_picker/file_picker.dart';
import 'package:flutter/material.dart';
import 'package:impact/0_Impact_Global/2_Shared_Preference.dart';

late PlatformFile ImpactSingleImageFile;
late String ImpactSingleImageFileB64;

class ImpactSingleImage extends StatefulWidget {
  @override
  State<StatefulWidget> createState() {
    return ImpactSingleImageState();
  }
}

class ImpactSingleImageState extends State<ImpactSingleImage> {
   bool IsChanged = false;

  Future<void> PickImage() async {
    await FilePicker.platform.pickFiles(
      allowMultiple:false,
      type: FileType.image,
      withData:true,
    ).then((files)  async {
      if(files != null && files.count>0){
        files.files.forEach((element) {
          ImpactSingleImageFile     = element;
          ImpactSingleImageFileB64  = "data:image/png;base64,"+base64Encode(element.bytes!);
          setState(() {
            IsChanged=true;
          });
        });
      }
    });
    print("~~~~~~~~~~~~~ImpactSingleImageFile~~~~~~~~~~~");
    print(ImpactSingleImageFile);
    print("~~~~~~~~~~~~~ImpactSingleImageFileB64~~~~~~~~~~~");
    print(ImpactSingleImageFileB64);
  }

  @override
  Widget build(BuildContext context) {
    return Container(
          width:ImpactScreenWidth,
          height:210.0,
          child:Center(
            child: Stack(
              children: [

                ClipOval(
                  child:Container(
                    decoration:BoxDecoration(
                      // border:Border.all(
                      //   color:ImpactPrimaryColor,
                      //   width:1
                      // )
                    ),
                    child:(IsChanged==false)?Image.network(
                      ImpactUserProfilePic,
                      width:150,
                      height:150,
                      fit:BoxFit.cover,
                    ):Image.memory(
                        ImpactSingleImageFile.bytes!,
                        width:150,
                        height:150,
                        fit:BoxFit.cover,
                    )
                  )
                ),

                Padding(
                  padding: const EdgeInsets.only(
                      top:108.0,
                      left:108.0
                  ),
                  child: ClipOval(
                    child:Container(
                      width:40,
                      height:40,
                      color:ImpactPrimaryColor,
                      child:IconButton(
                          icon:Icon(Icons.edit),
                          onPressed:(){
                            PickImage();
                          }
                      ),
                    )
                  ),
                )

              ],
            ),
          )
    );
  }

}

==> impact-0.0.5.tar.gz: lib/11_Images/1_Single_Image.dart <==
import 'dart:convert';
import 'package:file_picker/file_picker.dart';
import 'package:flutter/material.dart';
import 'package:impact/0_Impact_Global/2_Shared_Preference.dart';

late PlatformFile ImpactSingleImageFile;
late String ImpactSingleImageFileB64;

class ImpactSingleImage extends StatefulWidget {
  String? InitImage;

  ImpactSingleImage({
    this.InitImage
  });


  @override
  State<StatefulWidget> createState() {
    return ImpactSingleImageState();
  }
}

class ImpactSingleImageState extends State<ImpactSingleImage> {
   bool IsChanged = false;


   @override
   void initState(){
     super.initState();
     if(ImpactUserProfilePic==null){
       ImpactUserProfilePic="https://www.neappoli.com/static/media/flutterImg.94b8139a.png";
     }
   }

  Future<void> PickImage() async {
    await FilePicker.platform.pickFiles(
      allowMultiple:false,
      type: FileType.image,
      withData:true,
    ).then((files)  async {
      if(files != null && files.count>0){
        files.files.forEach((element) {
          ImpactSingleImageFile     = element;
          ImpactSingleImageFileB64  = "data:image/png;base64,"+base64Encode(element.bytes!);
          setState(() {
            IsChanged=true;
          });
        });
      }
    });
    print("~~~~~~~~~~~~~ImpactSingleImageFile~~~~~~~~~~~");
    print(ImpactSingleImageFile);
    print("~~~~~~~~~~~~~ImpactSingleImageFileB64~~~~~~~~~~~");
    print(ImpactSingleImageFileB64);
  }

  @override
  Widget build(BuildContext context) {
    return Container(
          width:ImpactScreenWidth,
          height:210.0,
          child:Center(
            child: Stack(
              children: [

                ClipOval(
                  child:Container(
                    decoration:BoxDecoration(
                      // border:Border.all(
                      //   color:ImpactPrimaryColor,
                      //   width:1
                      // )
                    ),
                    child:(IsChanged==false)?Image.network(
                      (this.widget.InitImage==null)?ImpactUserProfilePic:this.widget.InitImage,
                      width:150,
                      height:150,
                      fit:BoxFit.cover,
                    ):Image.memory(
                        ImpactSingleImageFile.bytes!,
                        width:150,
                        height:150,
                        fit:BoxFit.cover,
                    )
                  )
                ),

                Padding(
                  padding: const EdgeInsets.only(
                      top:108.0,
                      left:108.0
                  ),
                  child: ClipOval(
                    child:Container(
                      width:40,
                      height:40,
                      color:ImpactPrimaryColor,
                      child:IconButton(
                          icon:Icon(Icons.edit),
                          onPressed:(){
                            PickImage();
                          }
                      ),
                    )
                  ),
                )

              ],
            ),
          )
    );
  }

}
